@@ -123,6 +123,7 @@ transfer.  For example:
 
 
 """
+
 import concurrent.futures
 import functools
 import logging
@@ -135,7 +136,7 @@ import string
 import threading
 
 from botocore.compat import six  # noqa: F401
-from botocore.exceptions import IncompleteReadError
+from botocore.exceptions import IncompleteReadError, ResponseStreamingError
 from botocore.vendored.requests.packages.urllib3.exceptions import (
     ReadTimeoutError,
 )
@@ -144,7 +145,7 @@ import s3transfer.compat
 from s3transfer.exceptions import RetriesExceededError, S3UploadFailedError
 
 __author__ = 'Amazon Web Services'
-__version__ = '0.10.0'
+__version__ = '0.10.3'
 
 
 class NullHandler(logging.Handler):
@@ -624,6 +625,7 @@ class MultipartDownloader:
                     OSError,
                     ReadTimeoutError,
                     IncompleteReadError,
+                    ResponseStreamingError,
                 ) as e:
                     logger.debug(
                         "Retrying exception caught (%s), "
@@ -812,8 +814,8 @@ class S3Transfer:
         for kwarg in actual:
             if kwarg not in allowed:
                 raise ValueError(
-                    "Invalid extra_args key '%s', "
-                    "must be one of: %s" % (kwarg, ', '.join(allowed))
+                    f"Invalid extra_args key '{kwarg}', "
+                    f"must be one of: {', '.join(allowed)}"
                 )
 
     def _ranged_download(
@@ -840,6 +842,7 @@ class S3Transfer:
                 OSError,
                 ReadTimeoutError,
                 IncompleteReadError,
+                ResponseStreamingError,
             ) as e:
                 # TODO: we need a way to reset the callback if the
                 # download failed.
